@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: engine.cpp 4541 2008-08-28 18:32:11Z b_lindeijer $
  */
 
 #include "engine.h"
@@ -31,7 +29,6 @@
 #include "flooritemmanager.h"
 #include "game.h"
 #include "graphics.h"
-#include "main.h"
 #include "localplayer.h"
 #include "log.h"
 #include "main.h"
@@ -70,10 +67,15 @@ Engine::~Engine()
 
 void Engine::changeMap(const std::string &mapPath)
 {
-    // Clean up floor items
+    // Clean up floor items, beings and particles
     floorItemManager->clear();
-
     beingManager->clear();
+
+    // Unset the map of the player so that its particles are cleared before
+    // being deleted in the next step
+    if (player_node)
+        player_node->setMap(0);
+
     particleEngine->clear();
 
     // Store full map path in global var
@@ -97,6 +99,12 @@ void Engine::changeMap(const std::string &mapPath)
     {
         mapImage = resman->getImage(newMap->getProperty("minimap"));
     }
+    if (newMap->hasProperty("name"))
+    {
+        minimap->setCaption(newMap->getProperty("name"));
+    } else {
+        minimap->setCaption("Map");
+    }
     minimap->setMapImage(mapImage);
     beingManager->setMap(newMap);
     particleEngine->setMap(newMap);
