@@ -17,34 +17,26 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: equipment.cpp 4347 2008-06-12 09:06:01Z b_lindeijer $
  */
 
 #include "equipment.h"
+#include "item.h"
+#include "inventory.h"
+#include "localplayer.h"
 
 #include <algorithm>
 
-#include "item.h"
-#include "item.h"
-
 Equipment::Equipment():
     mArrows(0)
 {
-    std::fill_n(mEquipment, EQUIPMENT_SIZE, (Item*) 0);
+    std::fill_n(mEquipment, EQUIPMENT_SIZE, 0);
 }
 
 void
-Equipment::removeEquipment(Item *item)
+Equipment::setEquipment(int index, int inventoryIndex)
 {
-    Item **i = std::find(mEquipment, mEquipment + EQUIPMENT_SIZE, item);
-    if (i != mEquipment + EQUIPMENT_SIZE) {
-        *i = 0;
-    }
-}
-
-void Equipment::setEquipment(int index, Item *item)
-{
-    mEquipment[index] = item;
-    item->setEquipped(true);
+    mEquipment[index] = inventoryIndex;
+    Item* item = player_node->getInventory()->getItem(inventoryIndex);
+    if (item)
+    	item->setEquipped(true);
 }
