@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: equipment.h 4347 2008-06-12 09:06:01Z b_lindeijer $
  */
 
 #ifndef _TMW_EQUIPMENT_H_
@@ -39,41 +37,32 @@ class Equipment
         /**
          * Get equipment at the given slot.
          */
-        Item* getEquipment(int index) const
+        int getEquipment(int index) const
         { return mEquipment[index]; }
 
         /**
          * Set equipment at the given slot.
          */
-        void
-        setEquipment(int index, Item *item);
+        void setEquipment(int index, int inventoryIndex);
 
         /**
          * Remove equipment from the given slot.
          */
-        void
-        removeEquipment(int index) { mEquipment[index] = 0; }
+        void removeEquipment(int index) { if (index >= 0 && index < EQUIPMENT_SIZE) mEquipment[index] = 0; }
 
         /**
-         * Remove the given item from equipment.
+         * Returns the item used in the arrow slot.
          */
-        void removeEquipment(Item *item);
-
-        /**
-         * Get the item used in the arrow slot.
-         */
-        Item*
-        getArrows() { return mArrows; }
+        int getArrows() const { return mArrows; }
 
         /**
          * Set the item used in the arrow slot.
          */
-        void
-        setArrows(Item *arrows) { mArrows = arrows; }
+        void setArrows(int arrows) { mArrows = arrows; }
 
     private:
-        Item *mEquipment[EQUIPMENT_SIZE];
-        Item *mArrows;
+        int mEquipment[EQUIPMENT_SIZE];
+        int mArrows;
 };
 
 #endif
