@@ -17,12 +17,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: flooritemmanager.cpp 3754 2007-11-20 15:19:50Z b_lindeijer $
  */
 
-#include <algorithm>
-
 #include "flooritemmanager.h"
 
 #include "floor_item.h"
@@ -50,7 +46,7 @@ void FloorItemManager::destroy(FloorItem *item)
 
 void FloorItemManager::clear()
 {
-    for_each(mFloorItems.begin(), mFloorItems.end(), make_dtor(mFloorItems));
+    delete_all(mFloorItems);
     mFloorItems.clear();
 }
 
