@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: game.cpp 4540 2008-08-28 18:01:15Z b_lindeijer $
  */
 
 #include "game.h"
@@ -47,7 +45,6 @@
 
 #include "gui/buy.h"
 #include "gui/buysell.h"
-//#include "gui/chargedialog.h"
 #include "gui/chat.h"
 #include "gui/confirm_dialog.h"
 #include "gui/debugwindow.h"
@@ -114,11 +111,9 @@ InventoryWindow *inventoryWindow;
 NpcListDialog *npcListDialog;
 NpcTextDialog *npcTextDialog;
 SkillDialog *skillDialog;
-//NewSkillDialog *newSkillWindow;
 Setup* setupWindow;
 Minimap *minimap;
 EquipmentWindow *equipmentWindow;
-//ChargeDialog *chargeDialog;
 TradeWindow *tradeWindow;
 //BuddyWindow *buddyWindow;
 HelpWindow *helpWindow;
@@ -195,11 +190,9 @@ void createGuiWindows(Network *network)
     npcTextDialog = new NpcTextDialog();
     npcListDialog = new NpcListDialog();
     skillDialog = new SkillDialog();
-    //newSkillWindow = new NewSkillDialog();
     setupWindow = new Setup();
     minimap = new Minimap();
     equipmentWindow = new EquipmentWindow(player_node->mEquipment.get());
-    //chargeDialog = new ChargeDialog();
     tradeWindow = new TradeWindow(network);
     //buddyWindow = new BuddyWindow();
     helpWindow = new HelpWindow();
@@ -207,10 +200,6 @@ void createGuiWindows(Network *network)
     itemShortcutWindow = new ItemShortcutWindow();
 
     // Initialize window positions
-    //chargeDialog->setPosition(
-    //        graphics->getWidth() - 5 - chargeDialog->getWidth(),
-    //        graphics->getHeight() - chargeDialog->getHeight() - 15);
-
     //buddyWindow->setPosition(10, minimap->getHeight() + 30);
 
     // Set initial window visibility
@@ -221,6 +210,9 @@ void createGuiWindows(Network *network)
         true));
     buyDialog->setVisible(false);
     sellDialog->setVisible(false);
+    minimap->setVisible((bool) config.getValue(
+        minimap->getWindowName() + "Visible", true));
+    tradeWindow->setVisible(false);
     menuWindow->setVisible((bool) config.getValue(
         menuWindow->getWindowName() + "Visible", true));
     itemShortcutWindow->setVisible((bool) config.getValue(
@@ -251,8 +243,6 @@ void destroyGuiWindows()
     delete setupWindow;
     delete minimap;
     delete equipmentWindow;
-    //delete chargeDialog;
-    //delete newSkillWindow;
     delete tradeWindow;
     //delete buddyWindow;
     delete helpWindow;
@@ -298,9 +288,7 @@ Game::Game(Network *network):
     // TODO: The user should be able to choose which one to use
     // Open the first device
     if (Joystick::getNumberOfJoysticks() > 0)
-    {
         joystick = new Joystick(0);
-    }
 
     network->registerHandler(mBeingHandler.get());
     network->registerHandler(mBuySellHandler.get());
@@ -601,17 +589,6 @@ void Game::handleInput()
                     used = true;
                     break;
 
-                case SDLK_F2: requestedWindow = statusWindow; break;
-                case SDLK_F3: requestedWindow = inventoryWindow; break;
-                case SDLK_F4: requestedWindow = equipmentWindow; break;
-                case SDLK_F5: requestedWindow = skillDialog; break;
-                case SDLK_F6: requestedWindow = minimap; break;
-                case SDLK_F7: requestedWindow = chatWindow; break;
-                case SDLK_F8: requestedWindow = itemShortcutWindow; break;
-                case SDLK_F9: requestedWindow = setupWindow; break;
-                case SDLK_F10: requestedWindow = debugWindow; break;
-                //case SDLK_F11: requestedWindow = newSkillWindow; break;
-
                 case SDLK_RETURN:
                     // Input chat window
                     if (chatWindow->isInputFocused() ||
@@ -663,15 +640,19 @@ void Game::handleInput()
             if (keyboard.isEnabled() && !chatWindow->isInputFocused())
             {
                 const int tKey = keyboard.getKeyIndex(event.key.keysym.sym);
-                // Checks if any item shortcut is pressed.
-                for (int i = KeyboardConfig::KEY_SHORTCUT_0;
-                    i <= KeyboardConfig::KEY_SHORTCUT_9;
-                    i++)
+                // Do not activate shortcuts if tradewindow is visible
+                if (!tradeWindow->isVisible())
                 {
-                    if (tKey == i && !used) {
-                        itemShortcut->useItem(
-                                i - KeyboardConfig::KEY_SHORTCUT_0);
-                        break;
+                    // Checks if any item shortcut is pressed.
+                    for (int i = KeyboardConfig::KEY_SHORTCUT_0;
+                        i <= KeyboardConfig::KEY_SHORTCUT_9;
+                        i++)
+                    {
+                        if (tKey == i && !used) {
+                            itemShortcut->useItem(
+                                    i - KeyboardConfig::KEY_SHORTCUT_0);
+                            break;
+                        }
                     }
                 }
                 switch (tKey) {
@@ -721,6 +702,15 @@ void Game::handleInput()
                             debugWindow->setVisible(false);
                         }
                         break;
+                    case KeyboardConfig::KEY_WINDOW_STATUS: requestedWindow = statusWindow; break;
+                    case KeyboardConfig::KEY_WINDOW_INVENTORY: requestedWindow = inventoryWindow; break;
+                    case KeyboardConfig::KEY_WINDOW_EQUIPMENT: requestedWindow = equipmentWindow; break;
+                    case KeyboardConfig::KEY_WINDOW_SKILL: requestedWindow = skillDialog; break;
+                    case KeyboardConfig::KEY_WINDOW_MINIMAP: requestedWindow = minimap; break;
+                    case KeyboardConfig::KEY_WINDOW_CHAT: requestedWindow = chatWindow; break;
+                    case KeyboardConfig::KEY_WINDOW_SHORTCUT: requestedWindow = itemShortcutWindow; break;
+                    case KeyboardConfig::KEY_WINDOW_SETUP: requestedWindow = setupWindow; break;
+                    case KeyboardConfig::KEY_WINDOW_DEBUG: requestedWindow = debugWindow; break;
                 }
             }
 
