@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: chat.h 4402 2008-07-08 15:16:22Z the_enemy $
  */
 
 #ifndef _TMW_CHAT_H
@@ -48,18 +46,20 @@ class ScrollArea;
 
 #define BY_LOGGER     6
 
-#define IS_ANNOUNCE         "/announce "
-#define IS_ANNOUNCE_LENGTH  10
-#define IS_HELP             "/help"
-#define IS_HELP_LENGTH      5
-#define IS_WHERE            "/where"
-#define IS_WHERE_LENGTH     6
-#define IS_WHO              "/who"
-#define IS_WHO_LENGTH       4
-#define IS_CLEAR            "/clear"
-#define IS_CLEAR_LENGTH     6
-#define IS_WHISPER          "/whisper"
-#define IS_WHISPER_LENGTH   8
+#define IS_ANNOUNCE               "/announce "
+#define IS_ANNOUNCE_LENGTH        10
+#define IS_HELP                   "/help"
+#define IS_HELP_LENGTH            5
+#define IS_WHERE                  "/where"
+#define IS_WHERE_LENGTH           6
+#define IS_WHO                    "/who"
+#define IS_WHO_LENGTH             4
+#define IS_CLEAR                  "/clear"
+#define IS_CLEAR_LENGTH           6
+#define IS_WHISPER                "/whisper"
+#define IS_WHISPER_LENGTH         8
+#define IS_SHORT_WHISPER          "/w"
+#define IS_SHORT_WHISPER_LENGTH   2
 
 /**
  * gets in between usernick and message text depending on
@@ -127,9 +127,9 @@ class ChatWindow : public Window, public gcn::ActionListener,
         ChatWindow(Network *network);
 
         /**
-         * Logic (updates components' size)
+         * Called whenever the widget changes size.
          */
-        void logic();
+        void widgetResized(const gcn::Event &event);
 
         /*
          * Adds a line of text to our message list. Parameters:
@@ -221,6 +221,9 @@ class ChatWindow : public Window, public gcn::ActionListener,
         Network *mNetwork;
         bool mTmpVisible;
 
+        void
+        whisper(const std::string &nick, std::string msg, int prefixlen);
+
         /** One item in the chat log */
         struct CHATLOG
         {
