@@ -17,14 +17,13 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: equipmentwindow.h 2822 2006-11-05 14:30:53Z b_lindeijer $
  */
 
 #ifndef _TMW_EQUIPMENT_H
 #define _TMW_EQUIPMENT_H
 
 #include "window.h"
+#include "../inventory.h"
 
 class Equipment;
 
@@ -53,6 +52,7 @@ class EquipmentWindow : public Window
 
     private:
         Equipment *mEquipment;
+        Inventory *mInventory;
 };
 
 extern EquipmentWindow *equipmentWindow;
