@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: gui.cpp 3628 2007-10-18 18:39:48Z b_lindeijer $
  */
 
 #include "gui.h"
@@ -40,6 +38,7 @@
 #include "../graphics.h"
 #include "../log.h"
 
+#include "../resources/image.h"
 #include "../resources/imageset.h"
 #include "../resources/resourcemanager.h"
 #include "../resources/imageloader.h"
@@ -77,6 +76,8 @@ class GuiConfigListener : public ConfigListener
 Gui::Gui(Graphics *graphics):
     mCustomCursor(false),
     mMouseCursors(NULL),
+    mMouseCursorAlpha(1.0f),
+    mMouseInactivityTimer(0),
     mCursorType(CURSOR_POINTER)
 {
     logger->log("Initializing GUI...");
@@ -103,11 +104,21 @@ Gui::Gui(Graphics *graphics):
     Window::setWindowContainer(guiTop);
     setTop(guiTop);
 
-    // Set global font
+    // Set global font (based on ISO-8859-15)
     try {
         mGuiFont = new gcn::ImageFont("graphics/gui/sansserif8.png",
-                " !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ["
-                "\\]^_`abcdefghijklmnopqrstuvwxyz{|}~|"
+                " !\"#$%&'()*+,-./"
+                "0123456789:;<=>?"
+                "@ABCDEFGHIJKLMNO"
+                "PQRSTUVWXYZ[\\]^_"
+                "`abcdefghijklmno"
+                "pqrstuvwxyz{|}~|"
+                ""
+                ""
+                ""
+                ""
+                ""
+                ""
                 );
     }
     catch (gcn::Exception e)
@@ -166,32 +177,47 @@ Gui::~Gui()
     delete hitBlueFont;
     delete hitYellowFont;
 
-    if (mMouseCursors) {
+    if (mMouseCursors)
         mMouseCursors->decRef();
-    }
 
     delete mGuiFont;
     delete speechFont;
     delete viewport;
-    delete mTop;
+    delete getTop();
 
     delete guiInput;
 }
 
-void
-Gui::draw()
+void Gui::logic()
 {
-    mGraphics->pushClipArea(mTop->getDimension());
-    mTop->draw(mGraphics);
+    // Fade out mouse cursor after extended inactivity
+    if (mMouseInactivityTimer < 100 * 15) {
+        ++mMouseInactivityTimer;
+        mMouseCursorAlpha = std::min(1.0f, mMouseCursorAlpha + 0.05f);
+    } else {
+        mMouseCursorAlpha = std::max(0.0f, mMouseCursorAlpha - 0.005f);
+    }
+
+    gcn::Gui::logic();
+}
+
+void Gui::draw()
+{
+    mGraphics->pushClipArea(getTop()->getDimension());
+    getTop()->draw(mGraphics);
 
     int mouseX, mouseY;
     Uint8 button = SDL_GetMouseState(&mouseX, &mouseY);
 
-    if ((SDL_GetAppState() & SDL_APPMOUSEFOCUS || button & SDL_BUTTON(1)) &&
-            mCustomCursor)
+    if ((SDL_GetAppState() & SDL_APPMOUSEFOCUS || button & SDL_BUTTON(1))
+            && mCustomCursor
+            && mMouseCursorAlpha > 0.0f)
     {
+        Image *mouseCursor = mMouseCursors->get(mCursorType);
+        mouseCursor->setAlpha(mMouseCursorAlpha);
+
         static_cast<Graphics*>(mGraphics)->drawImage(
-                mMouseCursors->get(mCursorType),
+                mouseCursor,
                 mouseX - 15,
                 mouseY - 17);
     }
@@ -199,8 +225,7 @@ Gui::draw()
     mGraphics->popClipArea();
 }
 
-void
-Gui::setUseCustomCursor(bool customCursor)
+void Gui::setUseCustomCursor(bool customCursor)
 {
     if (customCursor != mCustomCursor)
     {
@@ -233,3 +258,9 @@ Gui::setUseCustomCursor(bool customCursor)
         }
     }
 }
+
+void Gui::handleMouseMoved(const gcn::MouseInput &mouseInput)
+{
+    gcn::Gui::handleMouseMoved(mouseInput);
+    mMouseInactivityTimer = 0;
+}
