@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: gui.h 3628 2007-10-18 18:39:48Z b_lindeijer $
  */
 
 #ifndef _TMW_GUI
@@ -59,6 +57,12 @@ class Gui : public gcn::Gui
          */
         ~Gui();
 
+        /**
+         * Performs logic of the GUI. Overridden to track mouse pointer
+         * activity.
+         */
+        void logic();
+
         /**
          * Draws the whole Gui by calling draw functions down in the
          * Gui hierarchy. It also draws the mouse pointer.
@@ -96,11 +100,16 @@ class Gui : public gcn::Gui
             CURSOR_TOTAL
         };
 
+    protected:
+        void handleMouseMoved(const gcn::MouseInput &mouseInput);
+
     private:
         GuiConfigListener *mConfigListener;
         gcn::Font *mGuiFont;                  /**< The global GUI font */
         bool mCustomCursor;                   /**< Show custom cursor */
         ImageSet *mMouseCursors;              /**< Mouse cursor images */
+        float mMouseCursorAlpha;
+        int mMouseInactivityTimer;
         int mCursorType;
 };
 
