@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: minimap.cpp 4116 2008-04-17 12:48:43Z peaveydk $
  */
 
 #include "minimap.h"
@@ -42,42 +40,61 @@ Minimap::Minimap():
 Minimap::~Minimap()
 {
     if (mMapImage)
-    {
         mMapImage->decRef();
-    }
 }
 
 void Minimap::setMapImage(Image *img)
 {
     if (mMapImage)
-    {
         mMapImage->decRef();
-    }
 
     mMapImage = img;
 
     if (mMapImage)
-    {
         mMapImage->setAlpha(0.7);
-    }
 }
 
 void Minimap::draw(gcn::Graphics *graphics)
 {
     Window::draw(graphics);
 
-    if (mMapImage != NULL)
+    const gcn::Rectangle a = getChildrenArea();
+
+    graphics->pushClipArea(a);
+
+    int mapOriginX = 0;
+    int mapOriginY = 0;
+
+    if (mMapImage)
     {
+        if (mMapImage->getWidth() > a.width ||
+            mMapImage->getHeight() > a.height)
+        {
+            mapOriginX = (a.width - player_node->mX) / 2;
+            mapOriginY = (a.height - player_node->mY) / 2;
+
+            const int minOriginX = a.width - mMapImage->getWidth();
+            const int minOriginY = a.height - mMapImage->getHeight();
+
+            if (mapOriginX < minOriginX)
+                mapOriginX = minOriginX;
+            if (mapOriginY < minOriginY)
+                mapOriginY = minOriginY;
+            if (mapOriginX > 0)
+                mapOriginX = 0;
+            if (mapOriginY > 0)
+                mapOriginY = 0;
+        }
         static_cast<Graphics*>(graphics)->
-            drawImage(mMapImage, getPadding(), getTitleBarHeight());
+            drawImage(mMapImage, mapOriginX, mapOriginY);
     }
 
-    Beings &beings = beingManager->getAll();
-    BeingIterator bi;
+    const Beings &beings = beingManager->getAll();
+    Beings::const_iterator bi;
 
     for (bi = beings.begin(); bi != beings.end(); bi++)
     {
-        Being *being = (*bi);
+        const Being *being = (*bi);
         int dotSize = 2;
 
         switch (being->getType()) {
@@ -103,11 +120,12 @@ void Minimap::draw(gcn::Graphics *graphics)
                 continue;
         }
 
-        int offset = (dotSize - 1) / 2;
-
+        const int offset = (dotSize - 1) / 2;
         graphics->fillRectangle(gcn::Rectangle(
-                    being->mX / 2 + getPadding() - offset,
-                    being->mY / 2 + getTitleBarHeight() - offset,
+                    being->mX / 2 + mapOriginX - offset,
+                    being->mY / 2 + mapOriginY - offset,
                     dotSize, dotSize));
     }
+
+    graphics->popClipArea();
 }
