@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: ministatus.cpp 4541 2008-08-28 18:32:11Z b_lindeijer $
  */
 
 #include "ministatus.h"
@@ -76,11 +74,32 @@ MiniStatusWindow::MiniStatusWindow():
     add(mMpLabel);
     add(mXpLabel);
 
-    setDefaultSize(0, 0, mXpBar->getX() + mXpBar->getWidth(),
+    setContentSize(mXpBar->getX() + mXpBar->getWidth(),
                    mXpBar->getY() + mXpBar->getHeight());
+    setDefaultSize(0, 0, getWidth(), getHeight());
     loadWindowState();
 }
 
+void
+MiniStatusWindow::setIcon(int index, AnimatedSprite *sprite)
+{
+    if (index >= (int) mIcons.size())
+        mIcons.resize(index + 1, NULL);
+
+    if (mIcons[index])
+        delete mIcons[index];
+
+    mIcons[index] = sprite;
+}
+
+void
+MiniStatusWindow::eraseIcon(int index)
+{
+    mIcons.erase(mIcons.begin() + index);
+}
+
+extern volatile int tick_time;
+
 void MiniStatusWindow::update()
 {
     // HP Bar coloration
@@ -99,6 +118,11 @@ void MiniStatusWindow::update()
 
     mHpBar->setProgress((float) player_node->mHp / player_node->mMaxHp);
     mMpBar->setProgress((float) player_node->mMp / player_node->mMaxMp);
+    if (player_node->MATK <= 0)
+        mMpBar->setColor(100, 100, 100); // grey, to indicate that we lack magic
+    else
+        mMpBar->setColor(26, 102, 230); // blue, to indicate that we have magic
+
     mXpBar->setProgress(
             (float) player_node->getXp() / player_node->mXpForNextLevel);
 
@@ -125,10 +149,27 @@ void MiniStatusWindow::update()
     */
 
     mXpLabel->setCaption(updatedText.str());
+
+    for (unsigned int i = 0; i < mIcons.size(); i++)
+        if (mIcons[i])
+            mIcons[i]->update(tick_time * 10);
+
 }
 
-void MiniStatusWindow::draw(gcn::Graphics *graphics)
+void MiniStatusWindow::draw(gcn::Graphics *gcn_graphics)
 {
     update();
-    drawChildren(graphics);
+    drawChildren(gcn_graphics);
+}
+
+void
+MiniStatusWindow::drawIcons(Graphics *graphics)
+{
+    // Draw icons
+    int icon_x = mXpBar->getX() + mXpBar->getWidth() + 4;
+    for (unsigned int i = 0; i < mIcons.size(); i++)
+        if (mIcons[i]) {
+            mIcons[i]->draw(graphics, icon_x, 3);
+            icon_x += 2 + mIcons[i]->getWidth();
+        }
 }
