@@ -17,18 +17,18 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: ministatus.h 2822 2006-11-05 14:30:53Z b_lindeijer $
  */
 
 #ifndef _TMW_MINISTATUS_H
 #define _TMW_MINISTATUS_H
 
 #include <iosfwd>
+#include <vector>
 
 #include "window.h"
 
 #include "../guichanfwd.h"
+#include "../animatedsprite.h"
 
 class ProgressBar;
 
@@ -50,6 +50,15 @@ class MiniStatusWindow : public Window
          */
         void draw(gcn::Graphics *graphics);
 
+        /**
+         * Sets one of the icons
+         */
+        void setIcon(int index, AnimatedSprite *sprite);
+
+        void eraseIcon(int index);
+
+        void drawIcons(Graphics *graphics);
+
     private:
         /**
          * Updates this dialog with values from player_node
@@ -65,6 +74,8 @@ class MiniStatusWindow : public Window
         gcn::Label *mHpLabel;
         gcn::Label *mMpLabel;
         gcn::Label *mXpLabel;
+
+        std::vector<AnimatedSprite *> mIcons;
 };
 
 #endif
