@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: npclistdialog.h 3035 2007-01-14 14:54:39Z b_lindeijer $
  */
 
 #ifndef _TMW_GUI_NPCLISTDIALOG_H
@@ -50,42 +48,47 @@ class NpcListDialog : public Window, public gcn::ActionListener,
          */
         NpcListDialog();
 
+        /**
+         * Called when resizing the window
+         *
+         * @param event The calling event
+         */
+        void widgetResized(const gcn::Event &event);
+
         /**
          * Called when receiving actions from the widgets.
          */
-        void
-        action(const gcn::ActionEvent &event);
+        void action(const gcn::ActionEvent &event);
 
         /**
          * Returns the number of items in the choices list.
          */
-        int
-        getNumberOfElements();
+        int getNumberOfElements();
 
         /**
          * Returns the name of item number i of the choices list.
          */
-        std::string
-        getElementAt(int i);
+        std::string getElementAt(int i);
 
         /**
          * Fills the options list for an NPC dialog.
          *
          * @param itemString A string with the options separated with colons.
          */
-        void
-        parseItems(const std::string &itemString);
+        void parseItems(const std::string &itemString);
 
         /**
          * Resets the list by removing all items.
          */
-        void
-        reset();
+        void reset();
 
     private:
         gcn::ListBox *mItemList;
+        gcn::ScrollArea *scrollArea;
+        gcn::Button *okButton;
+        gcn::Button *cancelButton;
 
         std::vector<std::string> mItems;
 };
 
-#endif
+#endif // _TMW_GUI_NPCLISTDIALOG_H
