@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: setup_video.cpp 4462 2008-08-05 12:06:40Z the_enemy $
  */
 
 #include "setup_video.h"
@@ -107,8 +105,8 @@ Setup_Video::Setup_Video():
     mOpenGLEnabled(config.getValue("opengl", 0)),
     mCustomCursorEnabled(config.getValue("customcursor", 1)),
     mOpacity(config.getValue("guialpha", 0.8)),
-    mFps((int)config.getValue("fpslimit", 60)),
-    mModeListModel(new ModeListModel()),
+    mFps((int) config.getValue("fpslimit", 0)),
+    mModeListModel(new ModeListModel),
     mModeList(new ListBox(mModeListModel)),
     mFsCheckBox(new CheckBox("Full screen", mFullScreenEnabled)),
     mOpenGLCheckBox(new CheckBox("OpenGL", mOpenGLEnabled)),
@@ -116,13 +114,13 @@ Setup_Video::Setup_Video():
     mAlphaSlider(new Slider(0.2, 1.0)),
     mFpsCheckBox(new CheckBox("FPS Limit: ")),
     mFpsSlider(new Slider(10, 200)),
-    mFpsField(new TextField()),
-    mOriginalScrollLaziness((int) config.getValue("ScrollLaziness", 32)),
+    mFpsField(new TextField),
+    mOriginalScrollLaziness((int) config.getValue("ScrollLaziness", 16)),
     mScrollLazinessSlider(new Slider(1, 64)),
-    mScrollLazinessField(new TextField()),
-    mOriginalScrollRadius((int) config.getValue("ScrollRadius", 32)),
+    mScrollLazinessField(new TextField),
+    mOriginalScrollRadius((int) config.getValue("ScrollRadius", 0)),
     mScrollRadiusSlider(new Slider(0, 128)),
-    mScrollRadiusField(new TextField()),
+    mScrollRadiusField(new TextField),
     mOverlayDetail((int) config.getValue("OverlayDetail", 2)),
     mOverlayDetailSlider(new Slider(0, 2)),
     mOverlayDetailField(new gcn::Label("")),
@@ -280,9 +278,18 @@ void Setup_Video::apply()
     bool fullscreen = mFsCheckBox->isSelected();
     if (fullscreen != (config.getValue("screen", 0) == 1))
     {
+        /* The OpenGL test is only necessary on Windows, since switching
+         * to/from full screen works fine on Linux. On Windows we'd have to
+         * reinitialize the OpenGL state and reload all textures.
+         *
+         * See http://libsdl.org/cgi/docwiki.cgi/SDL_SetVideoMode
+         */
+
+#ifdef WIN32
         // checks for opengl usage
         if (!(config.getValue("opengl", 0) == 1))
         {
+#endif
             if (!graphics->setFullscreen(fullscreen))
             {
                 fullscreen = !fullscreen;
@@ -296,10 +303,12 @@ void Setup_Video::apply()
                     logger->error(error.str());
                 }
             }
+#ifdef WIN32
         } else {
             new OkDialog("Switching to full screen",
                     "Restart needed for changes to take effect.");
         }
+#endif
         config.setValue("screen", fullscreen ? 1 : 0);
     }
 
