@@ -17,16 +17,12 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: shop.cpp 4348 2008-06-14 12:42:49Z the_enemy $
  */
 
 #include "shop.h"
 
 #include "../utils/dtor.h"
 
-#include <algorithm>
-
 ShopItems::~ShopItems()
 {
     clear();
@@ -61,7 +57,7 @@ ShopItem* ShopItems::at(int i) const
 
 void ShopItems::clear()
 {
-    std::for_each(mShopItems.begin(), mShopItems.end(), make_dtor(mShopItems));
+    delete_all(mShopItems);
     mShopItems.clear();
 }
 
