@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: status.cpp 3510 2007-08-23 14:14:51Z b_lindeijer $
  */
 
 #include "status.h"
@@ -41,7 +39,7 @@ StatusWindow::StatusWindow(LocalPlayer *player):
     setResizable(true);
     setCloseButton(true);
     setDefaultSize((windowContainer->getWidth() - 365) / 2,
-                   (windowContainer->getHeight() - 255) / 2, 365, 255);
+                   (windowContainer->getHeight() - 255) / 2, 365, 275);
     loadWindowState();
 
     // ----------------------
@@ -50,6 +48,7 @@ StatusWindow::StatusWindow(LocalPlayer *player):
 
     mLvlLabel = new gcn::Label("Level:");
     mGpLabel = new gcn::Label("Money:");
+    mJobLvlLabel = new gcn::Label("Job:");
 
     mHpLabel = new gcn::Label("HP:");
     mHpBar = new ProgressBar(1.0f, 80, 15, 0, 171, 34);
@@ -64,7 +63,7 @@ StatusWindow::StatusWindow(LocalPlayer *player):
     mMpValueLabel = new gcn::Label("");
 
     mJobXpLabel = new gcn::Label("Job:");
-    mJobXpBar = new ProgressBar(1.0f, 60, 15, 220, 135, 203);
+    mJobXpBar = new ProgressBar(1.0f, 80, 15, 220, 135, 203);
     mJobValueLabel = new gcn::Label("");
 
     int y = 3;
@@ -72,6 +71,8 @@ StatusWindow::StatusWindow(LocalPlayer *player):
 
     mLvlLabel->setPosition(x, y);
     x += mLvlLabel->getWidth() + 40;
+    mJobLvlLabel->setPosition(x, y);
+    x += mJobLvlLabel->getWidth() + 40;
     mGpLabel->setPosition(x, y);
 
     y += mLvlLabel->getHeight() + 5; // Next Row
@@ -97,10 +98,11 @@ StatusWindow::StatusWindow(LocalPlayer *player):
     mMpValueLabel->setPosition(x, y);
 
     mJobXpLabel->setPosition(175, y);
-    mJobXpBar->setPosition(225, y);
+    mJobXpBar->setPosition(205, y);
     mJobValueLabel->setPosition(290, y);
 
     add(mLvlLabel);
+    add(mJobLvlLabel);
     add(mGpLabel);
     add(mHpLabel);
     add(mHpValueLabel);
@@ -228,12 +230,12 @@ void StatusWindow::update()
     mLvlLabel->setCaption("Level: " + toString(mPlayer->mLevel));
     mLvlLabel->adjustSize();
 
+    mJobLvlLabel->setCaption("Job: " + toString(mPlayer->mJobLevel));
+    mJobLvlLabel->adjustSize();
+
     mGpLabel->setCaption("Money: " + toString(mPlayer->mGp) + " GP");
     mGpLabel->adjustSize();
 
-    mJobXpLabel->setCaption("Job: " + toString(mPlayer->mJobLevel));
-    mJobXpLabel->adjustSize();
-
     mHpValueLabel->setCaption(toString(mPlayer->mHp) +
             "/" + toString(mPlayer->mMaxHp));
     mHpValueLabel->adjustSize();
@@ -265,7 +267,7 @@ void StatusWindow::update()
     }
 
     mHpBar->setProgress((float) mPlayer->mHp / (float) mPlayer->mMaxHp);
-    // mMpBar->setProgress((float)mPlayer->mp / (float)mPlayer->maxMp);
+    mMpBar->setProgress((float) mPlayer->mMp / (float) mPlayer->mMaxMp);
 
     mXpBar->setProgress(
             (float) mPlayer->getXp() / (float) mPlayer->mXpForNextLevel);
@@ -336,8 +338,10 @@ void StatusWindow::update()
     mStatsReflexPoints->adjustSize();
 
     // Update Second column widgets position
-    mGpLabel->setPosition(mLvlLabel->getX() + mLvlLabel->getWidth() + 20,
-                         mLvlLabel->getY());
+    mJobLvlLabel->setPosition(mLvlLabel->getX() + mLvlLabel->getWidth() + 20,
+                              mLvlLabel->getY());
+    mGpLabel->setPosition(mJobLvlLabel->getX() + mJobLvlLabel->getWidth() + 20,
+                          mJobLvlLabel->getY());
 
     mXpLabel->setPosition(
             mHpValueLabel->getX() + mHpValueLabel->getWidth() + 10,
@@ -349,11 +353,13 @@ void StatusWindow::update()
             mXpBar->getX() + mXpBar->getWidth() + 5,
             mXpLabel->getY());
 
-    mJobXpLabel->setPosition(mXpLabel->getX(), mMpLabel->getY());
+    mJobXpLabel->setPosition(mXpBar->getX() - mJobXpLabel->getWidth() - 5, 
+                             mMpLabel->getY());
     mJobXpBar->setPosition(
-            mXpBar->getX() + mXpBar->getWidth() - mJobXpBar->getWidth(),
+            mJobXpLabel->getX() + mJobXpLabel->getWidth() + 5,
             mJobXpLabel->getY());
-    mJobValueLabel->setPosition(290, mJobXpLabel->getY());
+    mJobValueLabel->setPosition(mJobXpBar->getX() + mJobXpBar->getWidth() + 5, 
+                                mJobXpLabel->getY());
 }
 
 void StatusWindow::draw(gcn::Graphics *g)
