@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: updatewindow.h 4332 2008-06-05 07:33:12Z b_lindeijer $
  */
 
 #ifndef _UPDATERWINDOW_H
@@ -32,12 +30,13 @@
 
 #include "../guichanfwd.h"
 
+#include "../utils/mutex.h"
+
 class BrowserBox;
 class Button;
 class ProgressBar;
 class ScrollArea;
 
-struct SDL_mutex;
 struct SDL_Thread;
 
 /**
@@ -90,7 +89,7 @@ class UpdaterWindow : public Window, public gcn::ActionListener
 
     int updateState;
 
- protected:
+private:
     void download();
 
     /**
@@ -135,6 +134,12 @@ class UpdaterWindow : public Window, public gcn::ActionListener
     /** The file currently downloading. */
     std::string mCurrentFile;
 
+    /** The new label caption to be set in the logic method. */
+    std::string mNewLabelCaption;
+
+    /** The mutex used to guard access to mNewLabelCaption. */
+    Mutex mLabelMutex;
+
     /** The Adler32 checksum of the file currently downloading. */
     unsigned long mCurrentChecksum;
 
@@ -166,7 +171,7 @@ class UpdaterWindow : public Window, public gcn::ActionListener
     Button *mCancelButton;        /**< Button to stop the update process. */
     Button *mPlayButton;          /**< Button to start playing. */
     ProgressBar *mProgressBar;    /**< Update progress bar. */
-    BrowserBox* mBrowserBox;      /**< Box to display news. */
+    BrowserBox *mBrowserBox;      /**< Box to display news. */
     ScrollArea *mScrollArea;      /**< Used to scroll news box. */
 };
 
