@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: viewport.cpp 4545 2008-08-28 20:29:06Z b_lindeijer $
  */
 
 #include "viewport.h"
@@ -27,6 +25,7 @@
 
 #include "gui.h"
 #include "popupmenu.h"
+#include "ministatus.h"
 
 #include "../simpleanimation.h"
 #include "../beingmanager.h"
@@ -64,8 +63,8 @@ Viewport::Viewport():
     setOpaque(false);
     addMouseListener(this);
 
-    mScrollLaziness = (int) config.getValue("ScrollLaziness", 32);
-    mScrollRadius = (int) config.getValue("ScrollRadius", 32);
+    mScrollLaziness = (int) config.getValue("ScrollLaziness", 16);
+    mScrollRadius = (int) config.getValue("ScrollRadius", 0);
     mScrollCenterOffsetX = (int) config.getValue("ScrollCenterOffsetX", 0);
     mScrollCenterOffsetY = (int) config.getValue("ScrollCenterOffsetY", 0);
 
@@ -139,6 +138,8 @@ Viewport::setMap(Map *map)
     mMap = map;
 }
 
+extern MiniStatusWindow *miniStatusWindow;
+
 void
 Viewport::draw(gcn::Graphics *gcnGraphics)
 {
@@ -260,7 +261,7 @@ Viewport::draw(gcn::Graphics *gcnGraphics)
     // Draw text
     if (textManager)
     {
-        textManager->draw(graphics, mPixelViewX, mPixelViewY);
+        textManager->draw(graphics, (int) mPixelViewX, (int) mPixelViewY);
     }
 
     // Draw player names, speech, and emotion sprite as needed
@@ -270,6 +271,9 @@ Viewport::draw(gcn::Graphics *gcnGraphics)
         (*i)->drawEmotion(graphics, -(int) mPixelViewX, -(int) mPixelViewY);
     }
 
+    if (miniStatusWindow)
+        miniStatusWindow->drawIcons(graphics);
+
     // Draw contained widgets
     WindowContainer::draw(gcnGraphics);
 }
