@@ -17,19 +17,15 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: windowcontainer.cpp 3754 2007-11-20 15:19:50Z b_lindeijer $
  */
 
-#include <algorithm>
-
 #include "windowcontainer.h"
 
 #include "../utils/dtor.h"
 
 void WindowContainer::logic()
 {
-    for_each(mDeathList.begin(), mDeathList.end(), make_dtor(mDeathList));
+    delete_all(mDeathList);
     mDeathList.clear();
 
     gcn::Container::logic();
