@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: keyboardconfig.h 4441 2008-07-22 15:26:00Z the_enemy $
  */
 
 #ifndef _TMW_KEYBOARDCONFIG_H
@@ -168,6 +166,15 @@ class KeyboardConfig
             KEY_SHORTCUT_7,
             KEY_SHORTCUT_8,
             KEY_SHORTCUT_9,
+            KEY_WINDOW_STATUS,
+            KEY_WINDOW_INVENTORY,
+            KEY_WINDOW_EQUIPMENT,
+            KEY_WINDOW_SKILL,
+            KEY_WINDOW_MINIMAP,
+            KEY_WINDOW_CHAT,
+            KEY_WINDOW_SHORTCUT,
+            KEY_WINDOW_SETUP,
+            KEY_WINDOW_DEBUG,
             KEY_TOTAL
         };
 
