@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: localplayer.cpp 4545 2008-08-28 20:29:06Z b_lindeijer $
  */
 
 #include "localplayer.h"
@@ -32,8 +30,10 @@
 #include "particle.h"
 #include "sound.h"
 #include "monster.h"
+#include "statuseffect.h"
 
 #include "gui/gui.h"
+#include "gui/ministatus.h"
 
 #include "net/messageout.h"
 #include "net/protocol.h"
@@ -44,8 +44,19 @@ LocalPlayer *player_node = NULL;
 
 LocalPlayer::LocalPlayer(Uint32 id, Uint16 job, Map *map):
     Player(id, job, map),
-    mXpForNextLevel(0),
+    mCharId(0),
+    mJobXp(0),
+    mLevel(0),
+    mJobLevel(0),
+    mXpForNextLevel(0), mJobXpForNextLevel(0),
+    mHp(0), mMaxHp(0), mMp(0), mMaxMp(0),
+    mGp(0),
     mAttackRange(0),
+    mTotalWeight(0), mMaxWeight(0),
+    ATK(0), MATK(0), DEF(0), MDEF(0), HIT(0), FLEE(0),
+    ATK_BONUS(0), MATK_BONUS(0), DEF_BONUS(0), MDEF_BONUS(0), FLEE_BONUS(0),
+    mStatPoint(0), mSkillPoint(0),
+    mStatsPointsToAttribute(0),
     mXp(0), mNetwork(0),
     mTarget(NULL), mPickUpTarget(NULL),
     mTrading(false), mGoingToTarget(false),
@@ -144,7 +155,7 @@ void LocalPlayer::unequipItem(Item *item)
     outMsg.writeInt16(item->getInvIndex());
 
     // Tidy equipment directly to avoid weapon still shown bug, for instance
-    mEquipment->removeEquipment(item);
+    mEquipment->removeEquipment(item->getInvIndex());
 }
 
 void LocalPlayer::useItem(Item *item)
@@ -410,9 +421,6 @@ void LocalPlayer::attack(Being *target, bool keep)
             setDirection(LEFT);
     }
 
-    // Implement charging attacks here
-    mLastAttackTime = 0;
-
     setAction(ATTACK);
     mWalkTime = tick_time;
 
@@ -480,3 +488,45 @@ void LocalPlayer::setGotoTarget(Being *target)
     mGoingToTarget = true;
     setDestination(target->mX, target->mY);
 }
+
+
+extern MiniStatusWindow *miniStatusWindow;
+
+void LocalPlayer::handleStatusEffect(StatusEffect *effect, int effectId)
+{
+    Being::handleStatusEffect(effect, effectId);
+
+
+
+    if (effect) {
+        effect->deliverMessage();
+        effect->playSFX();
+
+        AnimatedSprite *sprite = effect->getIcon();
+
+        if (!sprite) {
+            // delete sprite, if necessary
+            for (unsigned int i = 0; i < mStatusEffectIcons.size();)
+                if (mStatusEffectIcons[i] == effectId) {
+                    mStatusEffectIcons.erase(mStatusEffectIcons.begin() + i);
+                    miniStatusWindow->eraseIcon(i);
+                } else i++;
+        } else {
+            // replace sprite or append
+            bool found = false;
+
+            for (unsigned int i = 0; i < mStatusEffectIcons.size(); i++)
+                if (mStatusEffectIcons[i] == effectId) {
+                    miniStatusWindow->setIcon(i, sprite);
+                    found = true;
+                    break;
+                }
+
+            if (!found) { // add new
+                int offset = mStatusEffectIcons.size();
+                miniStatusWindow->setIcon(offset, sprite);
+                mStatusEffectIcons.push_back(effectId);
+            }
+        }
+    }
+}
