@@ -17,13 +17,13 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: localplayer.h 4545 2008-08-28 20:29:06Z b_lindeijer $
  */
 
 #ifndef _TMW_LOCALPLAYER_H
 #define _TMW_LOCALPLAYER_H
 
+#include <vector>
+
 #include "player.h"
 
 // TODO move into some sane place...
@@ -176,7 +176,7 @@ class LocalPlayer : public Player
          */
         int getXp() const { return mXp; }
 
-        Uint32 mCharId;
+        Uint32 mCharId;     /**< Used only during character selection. */
 
         Uint32 mJobXp;
         Uint16 mLevel;
@@ -198,9 +198,10 @@ class LocalPlayer : public Player
         Uint16 mStatPoint, mSkillPoint;
         Uint16 mStatsPointsToAttribute;
 
-        float mLastAttackTime; /**< Used to synchronize the charge dialog */
-
     protected:
+        virtual void
+        handleStatusEffect(StatusEffect *effect, int effectId);
+
         void walk(unsigned char dir);
 
         int mXp;            /**< Experience points. */
@@ -216,6 +217,8 @@ class LocalPlayer : public Player
         int mDestX;         /**< X coordinate of destination. */
         int mDestY;         /**< Y coordinate of destination. */
 
+        std::vector<int> mStatusEffectIcons;
+
         Inventory *mInventory;
 };
 
