@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: main.cpp 4460 2008-08-04 07:17:06Z peaveydk $
  */
 
 #include "main.h"
@@ -66,6 +64,7 @@
 #include "gui/ok_dialog.h"
 #include "gui/progressbar.h"
 #include "gui/register.h"
+#include "gui/setup.h"
 #include "gui/updatewindow.h"
 #include "gui/textfield.h"
 
@@ -88,6 +87,18 @@
 #include <SDL_syswm.h>
 #endif
 
+namespace {
+    Window *setupWindow = 0;
+
+    struct SetupListener : public gcn::ActionListener
+    {
+        /**
+         * Called when receiving actions from widget.
+         */
+        void action(const gcn::ActionEvent &event);
+    } listener;
+}
+
 // Account infos
 char n_server, n_character;
 
@@ -148,6 +159,7 @@ struct Options
     std::string playername;
     std::string configPath;
     std::string updateHost;
+    std::string dataPath;
 };
 
 /**
@@ -257,6 +269,9 @@ void init_engine(const Options &options)
     resman->addToSearchPath(homeDir, false);
 
     // Add the main data directory to our PhysicsFS search path
+    if (!options.dataPath.empty()) {
+        resman->addToSearchPath(options.dataPath, true);
+    }
     resman->addToSearchPath("data", true);
 #if defined __APPLE__
     CFBundleRef mainBundle = CFBundleGetMainBundle();
@@ -290,7 +305,7 @@ void init_engine(const Options &options)
     config.setValue("remember", 1);
     config.setValue("sfxVolume", 100);
     config.setValue("musicVolume", 60);
-    config.setValue("fpslimit", 60);
+    config.setValue("fpslimit", 0);
     config.setValue("updatehost", "http://updates.themanaworld.org");
     config.setValue("customcursor", 1);
     config.setValue("ChatLogLength", 128);
@@ -430,6 +445,7 @@ void printHelp()
         << "  -h --help       : Display this help" << std::endl
         << "  -v --version    : Display the version" << std::endl
         << "  -u --skipupdate : Skip the update process" << std::endl
+        << "  -d --data       : Directory to load game data from" << std::endl
         << "  -U --username   : Login with this username" << std::endl
         << "  -P --password   : Login with this password" << std::endl
         << "  -D --default    : Bypass the login process with default settings" << std::endl
@@ -450,12 +466,13 @@ void printVersion()
 
 void parseOptions(int argc, char *argv[], Options &options)
 {
-    const char *optstring = "hvuU:P:Dp:C:H:";
+    const char *optstring = "hvud:U:P:Dp:C:H:";
 
     const struct option long_options[] = {
         { "help",       no_argument,       0, 'h' },
         { "version",    no_argument,       0, 'v' },
         { "skipupdate", no_argument,       0, 'u' },
+        { "data",       required_argument, 0, 'd' },
         { "username",   required_argument, 0, 'U' },
         { "password",   required_argument, 0, 'P' },
         { "default",    no_argument,       0, 'D' },
@@ -469,9 +486,8 @@ void parseOptions(int argc, char *argv[], Options &options)
 
         int result = getopt_long(argc, argv, optstring, long_options, NULL);
 
-        if (result == -1) {
+        if (result == -1)
             break;
-        }
 
         switch (result) {
             default: // Unknown option
@@ -484,6 +500,9 @@ void parseOptions(int argc, char *argv[], Options &options)
             case 'u':
                 options.skipUpdate = true;
                 break;
+            case 'd':
+                options.dataPath = optarg;
+                break;
             case 'U':
                 options.username = optarg;
                 break;
@@ -592,7 +611,8 @@ void charLogin(Network *network, LoginData *loginData)
     outMsg.writeInt32(loginData->account_ID);
     outMsg.writeInt32(loginData->session_ID1);
     outMsg.writeInt32(loginData->session_ID2);
-    outMsg.writeInt16(0); // unknown
+    // [Fate] The next word is unused by the old char server, so we squeeze in tmw client version information
+    outMsg.writeInt16(TMW_CLIENT_PROTOCOL_VERSION);
     outMsg.writeInt8(loginData->sex);
 
     // We get 4 useless bytes before the real answer comes in
@@ -668,6 +688,7 @@ int main(int argc, char *argv[])
     Game *game = NULL;
     Window *currentDialog = NULL;
     Image *login_wallpaper = NULL;
+    setupWindow = new Setup();
 
     gcn::Container *top = static_cast<gcn::Container*>(gui->getTop());
 #ifdef PACKAGE_VERSION
@@ -680,6 +701,9 @@ int main(int argc, char *argv[])
     top->add(progressLabel, 15 + progressBar->getWidth(),
                             progressBar->getY() + 4);
     progressBar->setVisible(false);
+    gcn::Button *setup = new Button("Setup", "Setup", &listener);
+    setup->setPosition(top->getWidth() - setup->getWidth() - 3, 3);
+    top->add(setup);
 
     sound.playMusic("Magick - Real.ogg");
 
@@ -751,7 +775,16 @@ int main(int argc, char *argv[])
                 progressBar->setProgress(0.0f);
         }
 
-        graphics->drawImage(login_wallpaper, 0, 0);
+        if (graphics->getWidth() > login_wallpaper->getWidth() ||
+                graphics->getHeight() > login_wallpaper->getHeight())
+        {
+            graphics->setColor(gcn::Color(64, 64, 64));
+            graphics->fillRectangle(gcn::Rectangle(
+                        0, 0, graphics->getWidth(), graphics->getHeight()));
+        }
+        graphics->drawImage(login_wallpaper,
+                (graphics->getWidth() - login_wallpaper->getWidth()) / 2,
+                (graphics->getHeight() - login_wallpaper->getHeight()) / 2);
         gui->draw();
         graphics->updateScreen();
 
@@ -864,9 +897,13 @@ int main(int argc, char *argv[])
 #endif
                     delete progressBar;
                     delete progressLabel;
+                    delete setup;
+                    delete setupWindow;
                     progressBar = NULL;
                     progressLabel = NULL;
                     currentDialog = NULL;
+                    setup = NULL;
+                    setupWindow = NULL;
                     login_wallpaper->decRef();
                     login_wallpaper = NULL;
 
@@ -935,6 +972,8 @@ int main(int argc, char *argv[])
 #endif
     delete progressBar;
     delete progressLabel;
+    delete setup;
+    delete setupWindow;
 
     delete network;
     SDLNet_Quit();
@@ -948,3 +987,22 @@ int main(int argc, char *argv[])
     PHYSFS_deinit();
     return 0;
 }
+
+void SetupListener::action(const gcn::ActionEvent &event)
+{
+    Window *window = NULL;
+
+    if (event.getId() == "Setup")
+    {
+        window = setupWindow;
+    }
+
+    if (window)
+    {
+        window->setVisible(!window->isVisible());
+        if (window->isVisible())
+        {
+            window->requestMoveToTop();
+        }
+    }
+}
