@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: charserverhandler.cpp 4540 2008-08-28 18:01:15Z b_lindeijer $
  */
 
 #include "charserverhandler.h"
@@ -184,9 +182,6 @@ LocalPlayer* CharServerHandler::readPlayerData(MessageIn &msg, int &slot)
     tempPlayer->setGender(1 - mLoginData->sex);
 
     tempPlayer->mCharId = msg.readInt32();
-    tempPlayer->mTotalWeight = 0;
-    tempPlayer->mMaxWeight = 0;
-    tempPlayer->mLastAttackTime = 0;
     tempPlayer->setXp(msg.readInt32());
     tempPlayer->mGp = msg.readInt32();
     tempPlayer->mJobXp = msg.readInt32();
