@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: loginhandler.cpp 4536 2008-08-28 13:36:33Z crush_tmw $
  */
 
 #include "loginhandler.h"
@@ -110,10 +108,12 @@ void LoginHandler::handleMessage(MessageIn *msg)
                     errorMessage = "Rejected from server";
                     break;
                 case 4:
-                    errorMessage = "You have been banned from the game. Please contact the GM Team";
+
+                    errorMessage = "You have been permanently banned from the game. Please contact the GM Team";
                     break;
                 case 6:
-                    errorMessage = "You have been temporarily banned from the game. Please contact the GM team";
+                    errorMessage = "You have been temporarily banned from the game until "
+                          + msg->readString(20) + ".\n Please contact the GM team via the forums";
                     break;
                 case 9:
                     errorMessage = "This user name is already taken";
