@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: network.h 3234 2007-03-24 13:05:27Z b_lindeijer $
  */
 
 #ifndef _TMW_NETWORK_
@@ -29,6 +27,10 @@
 #include <SDL_thread.h>
 #include <string>
 
+#define TMW_CLIENT_PROTOCOL_VERSION	1
+	/**< Protocol version, reported to the eAthena char and mapserver who
+             can adjust the protocol accordingly */
+
 class MessageHandler;
 class MessageIn;
 
