@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: npchandler.cpp 4046 2008-04-07 15:41:22Z b_lindeijer $
  */
 
 #include "npchandler.h"
@@ -70,9 +68,15 @@ void NPCHandler::handleMessage(MessageIn *msg)
             npcTextDialog->setVisible(true);
             break;
 
-        case SMSG_NPC_NEXT:
         case SMSG_NPC_CLOSE:
-            // Next/Close button in NPC dialog, currently unused
+            id = msg->readInt32();
+            dynamic_cast<NPC*>(beingManager->findBeing(id));
+            if (current_npc == dynamic_cast<NPC*>(beingManager->findBeing(id)))
+            	current_npc = NULL;
+            break;
+
+        case SMSG_NPC_NEXT:
+            // Next button in NPC dialog, currently unused
             break;
     }
 }
