@@ -17,8 +17,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: particle.cpp 4534 2008-08-27 18:48:13Z b_lindeijer $
  */
 
 #include <algorithm>
@@ -70,12 +68,21 @@ Particle::Particle(Map *map):
     mMomentum(1.0f)
 {
     Particle::particleCount++;
-    if (mMap) setSpriteIterator(mMap->addSprite(this));
+    if (mMap)
+        setSpriteIterator(mMap->addSprite(this));
 }
 
+Particle::~Particle()
+{
+    // Remove from map sprite list
+    if (mMap)
+        mMap->removeSprite(mSpriteIterator);
+    // Delete child emitters and child particles
+    clear();
+    Particle::particleCount--;
+}
 
-void
-Particle::setupEngine()
+void Particle::setupEngine()
 {
     Particle::maxCount = (int)config.getValue("particleMaxCount", 3000);
     Particle::fastPhysics = (int)config.getValue("particleFastPhysics", 0);
@@ -84,17 +91,17 @@ Particle::setupEngine()
     logger->log("Particle engine set up");
 }
 
-void Particle::draw(Graphics *, int, int) const {}
-
-bool
-Particle::update()
+void Particle::draw(Graphics *, int, int) const
 {
-    if (!mMap) return false;
+}
+
+bool Particle::update()
+{
+    if (!mMap)
+        return false;
 
     if (mLifetimeLeft == 0)
-    {
         mAlive = false;
-    }
 
     Vector oldPos = mPos;
 
@@ -181,7 +188,7 @@ Particle::update()
                     e++
                 )
             {
-                Particles newParticles = (*e)->createParticles();
+                Particles newParticles = (*e)->createParticles(mLifetimePast);
                 for (   ParticleIterator p = newParticles.begin();
                         p != newParticles.end();
                         p++
@@ -224,9 +231,8 @@ Particle::update()
     return true;
 }
 
-Particle*
-Particle::addEffect(const std::string &particleEffectFile,
-                    int pixelX, int pixelY)
+Particle *Particle::addEffect(const std::string &particleEffectFile,
+                              int pixelX, int pixelY)
 {
     Particle *newParticle = NULL;
 
@@ -300,11 +306,9 @@ Particle::addEffect(const std::string &particleEffectFile,
     return newParticle;
 }
 
-
-Particle*
-Particle::addTextSplashEffect(const std::string &text,
-                              int colorR, int colorG, int colorB,
-                              gcn::Font *font, int x, int y)
+Particle *Particle::addTextSplashEffect(const std::string &text,
+                                        int colorR, int colorG, int colorB,
+                                        gcn::Font *font, int x, int y)
 {
     Particle *newParticle = new TextParticle(mMap, text, colorR, colorG, colorB,
                                              font);
@@ -322,9 +326,9 @@ Particle::addTextSplashEffect(const std::string &text,
     return newParticle;
 }
 
-Particle*
-Particle::addTextRiseFadeOutEffect(const std::string &text, gcn::Font *font,
-                                   int x, int y)
+Particle *Particle::addTextRiseFadeOutEffect(const std::string &text,
+                                             gcn::Font *font,
+                                             int x, int y)
 {
     Particle *newParticle = new TextParticle(mMap, text, 255, 255, 255, font);
     newParticle->setPosition(x, y, 0);
@@ -339,32 +343,18 @@ Particle::addTextRiseFadeOutEffect(const std::string &text, gcn::Font *font,
     return newParticle;
 }
 
-void
-Particle::setMap(Map *map)
+void Particle::setMap(Map *map)
 {
     mMap = map;
-    if (mMap) setSpriteIterator(mMap->addSprite(this));
+    if (mMap)
+        setSpriteIterator(mMap->addSprite(this));
 }
 
-
-Particle::~Particle()
+void Particle::clear()
 {
-    // Remove from map sprite list
-    if (mMap) mMap->removeSprite(mSpriteIterator);
-    // Delete child emitters and child particles
-    clear();
-    Particle::particleCount--;
-}
-
-
-void
-Particle::clear()
-{
-    std::for_each(mChildEmitters.begin(), mChildEmitters.end(),
-            make_dtor(mChildEmitters));
+    delete_all(mChildEmitters);
     mChildEmitters.clear();
 
-    std::for_each(mChildParticles.begin(), mChildParticles.end(),
-            make_dtor(mChildParticles));
+    delete_all(mChildParticles);
     mChildParticles.clear();
 }
