@@ -17,14 +17,10 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: action.cpp 3676 2007-10-23 08:02:22Z b_lindeijer $
  */
 
 #include "action.h"
 
-#include <algorithm>
-
 #include "animation.h"
 
 #include "../utils/dtor.h"
@@ -36,12 +32,10 @@ Action::Action()
 
 Action::~Action()
 {
-    std::for_each(mAnimations.begin(), mAnimations.end(),
-                  make_dtor(mAnimations));
+    delete_all(mAnimations);
 }
 
-Animation*
-Action::getAnimation(int direction) const
+Animation *Action::getAnimation(int direction) const
 {
     Animations::const_iterator i = mAnimations.find(direction);
 
@@ -55,8 +49,7 @@ Action::getAnimation(int direction) const
     return (i == mAnimations.end()) ? NULL : i->second;
 }
 
-void
-Action::setAnimation(int direction, Animation *animation)
+void Action::setAnimation(int direction, Animation *animation)
 {
     mAnimations[direction] = animation;
 }
