@@ -17,12 +17,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: monsterdb.cpp 4549 2008-08-29 09:32:39Z the_enemy $
  */
 
-#include <algorithm>
-
 #include "monsterdb.h"
 
 #include "resourcemanager.h"
@@ -140,19 +136,16 @@ MonsterDB::load()
     mLoaded = true;
 }
 
-void
-MonsterDB::unload()
+void MonsterDB::unload()
 {
-    for_each(mMonsterInfos.begin(), mMonsterInfos.end(),
-             make_dtor(mMonsterInfos));
+    delete_all(mMonsterInfos);
     mMonsterInfos.clear();
 
     mLoaded = false;
 }
 
 
-const MonsterInfo&
-MonsterDB::get(int id)
+const MonsterInfo &MonsterDB::get(int id)
 {
     MonsterInfoIterator i = mMonsterInfos.find(id);
 
