@@ -17,13 +17,12 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: dtor.h 2822 2006-11-05 14:30:53Z b_lindeijer $
  */
 
 #ifndef _TMW_UTILS_DTOR_H
 #define _TMW_UTILS_DTOR_H
 
+#include <algorithm>
 #include <functional>
 #include <utility>
 
@@ -46,4 +45,10 @@ inline dtor<typename Cont::value_type> make_dtor(Cont const&)
     return dtor<typename Cont::value_type>();
 }
 
+template<typename Container>
+inline void delete_all(Container &c)
+{
+    std::for_each(c.begin(), c.end(), make_dtor(c));
+}
+
 #endif
