@@ -17,14 +17,10 @@
  *  You should have received a copy of the GNU General Public License
  *  along with The Mana World; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- *  $Id: strprintf.cpp 3416 2007-08-06 06:20:14Z gmelquio $
  */
 
-#ifndef _TMW_UTILS_TOSTRING_H
-#define _TMW_UTILS_TOSTRING_H
-
 #include <cstdarg>
+#include <cstdio>
 
 #include "strprintf.h"
 
@@ -49,5 +45,3 @@ std::string strprintf(char const *format, ...)
     delete [] buf2;
     return res;
 }
-
-#endif
